@@ -4,7 +4,7 @@ use crate::items::keywords::WhenKeyword;
 use crate::items::styles::{Child, ColumnIndent, Newline, Space};
 use crate::items::symbols::{CommaSymbol, SemicolonSymbol};
 use crate::items::tokens::{AtomToken, CharToken, FloatToken, IntegerToken, VariableToken};
-use crate::parse::Parse;
+use crate::parse::{self, Parse};
 use crate::span::Span;
 
 pub mod bitstrings;
@@ -27,12 +27,22 @@ pub use self::records::RecordExpr;
 pub use self::strings::StringExpr;
 pub use self::tuples::TupleExpr;
 
-#[derive(Debug, Clone, Span, Parse, Format)]
+#[derive(Debug, Clone, Span, Format)]
 pub enum Expr {
     BinaryOpCall(Box<BinaryOpCallExpr>),
     NonLeftRecursive(NonLeftRecursiveExpr),
 }
 
+impl Parse for Expr {
+    fn parse(ts: &mut parse::TokenStream) -> parse::Result<Self> {
+        let expr: NonLeftRecursiveExpr = ts.parse()?;
+        match BinaryOpCallExpr::try_parse(ts, expr) {
+            Ok(expr) => Ok(Self::BinaryOpCall(Box::new(expr))),
+            Err(expr) => Ok(Self::NonLeftRecursive(expr)),
+        }
+    }
+}
+
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub enum NonLeftRecursiveExpr {
     List(Box<ListExpr>),
@@ -115,13 +125,63 @@ impl Format for MaybeInlineBody {
     }
 }
 
-#[derive(Debug, Clone, Span, Parse, Format)]
+#[derive(Debug, Clone, Span, Parse)]
 pub struct Guard {
     when: Space<WhenKeyword>,
     condition: ColumnIndent<GuardCondition>,
 }
 
+impl Format for Guard {
+    fn format(&self, fmt: &mut format::Formatter) -> format::Result<()> {
+        let format = |fmt: &mut format::Formatter| {
+            self.when.format(fmt)?;
+            self.condition.format(fmt)?;
+            Ok(())
+        };
+
+        if fmt.current_relative_column() < 2 {
+            fmt.subregion()
+                .trailing_columns(3) // ' ->'
+                .enter(format)?;
+        } else if fmt
+            .subregion()
+            .trailing_columns(3) // ' ->'
+            .forbid_too_long_line()
+            .forbid_multi_line()
+            .enter(format)
+            .is_err()
+        {
+            fmt.subregion()
+                .indent_offset(2)
+                .trailing_columns(3) // ' ->'
+                .enter_with_newline(format)?;
+        }
+        Ok(())
+    }
+}
+
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub struct GuardCondition {
     conditions: NonEmptyItems<Expr, Either<CommaSymbol, SemicolonSymbol>>,
 }
+
+#[cfg(test)]
+mod tests {
+    use crate::items::forms::Form;
+
+    #[test]
+    fn when_works() {
+        let texts = [
+            indoc::indoc! {"
+            foo(A) when A ->
+                A."},
+            indoc::indoc! {"
+            foo(A, B, C)
+              when A =:= B ->
+                C."},
+        ];
+        for text in texts {
+            crate::assert_format!(text, Form);
+        }
+    }
+}
