@@ -4,7 +4,7 @@ use crate::items::generics::{Args, Maybe};
 use crate::items::keywords;
 use crate::items::styles::{Child, RightSpace, Space};
 use crate::items::symbols::{self, ColonSymbol};
-use crate::parse::Parse;
+use crate::parse::{self, Parse};
 use crate::span::Span;
 
 #[derive(Debug, Clone, Span, Parse, Format)]
@@ -35,6 +35,22 @@ pub struct BinaryOpCallExpr {
     right: Expr,
 }
 
+impl BinaryOpCallExpr {
+    pub fn try_parse(
+        ts: &mut parse::TokenStream,
+        left: NonLeftRecursiveExpr,
+    ) -> Result<Self, NonLeftRecursiveExpr> {
+        match ts.parse::<(_, _)>() {
+            Ok((op, right)) => Ok(Self {
+                left: Child(left),
+                op,
+                right,
+            }),
+            Err(_) => Err(left),
+        }
+    }
+}
+
 impl Format for BinaryOpCallExpr {
     fn format(&self, fmt: &mut format::Formatter) -> format::Result<()> {
         self.left.format(fmt)?;
@@ -113,10 +129,13 @@ mod tests {
             "foo()",
             "Foo(1, 2, 3)",
             indoc::indoc! {"
-                (foo(Bar))(a,
-                           b,
-                           c())"},
+            (foo(Bar))(a,
+                       b,
+                       c())"},
             "foo:bar(baz)",
+            indoc::indoc! {"
+            foo(A *
+                10 * B / 1_0.0)"},
         ];
         for text in texts {
             crate::assert_format!(text, Expr);
